<?php

namespace Litecms\Contact\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Contact\Actions\DocumentAction;
use Litecms\Contact\Http\Requests\DocumentActionRequest;
use Litecms\Contact\Http\Resources\DocumentResource;
use Litecms\Contact\Models\Document;

/**
 * Admin web controller class.
 */
class DocumentActionController extends BaseController
{

    /**
     * Action controller function for document.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(DocumentActionRequest $request, Document $document, $action)
    {
        try {
            $request = $request->all();
            $document = DocumentAction::run($action, $document, $request);

            $data = new DocumentResource($document);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('contact::document.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('contact/document/' . $document->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contact/document/' . $document->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
