<?php

namespace Litecms\Contact\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Contact\Actions\LandlordAction;
use Litecms\Contact\Http\Requests\LandlordActionRequest;
use Litecms\Contact\Http\Resources\LandlordResource;
use Litecms\Contact\Models\Landlord;

/**
 * Admin web controller class.
 */
class LandlordActionController extends BaseController
{

    /**
     * Action controller function for landlord.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LandlordActionRequest $request, Landlord $landlord, $action)
    {
        try {
            $request = $request->all();
            $landlord = LandlordAction::run($action, $landlord, $request);

            $data = new LandlordResource($landlord);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('contact::landlord.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('contact/landlord/' . $landlord->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contact/landlord/' . $landlord->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
