<?php

namespace Litecms\Contact\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Contact\Actions\LandlordContractAction;
use Litecms\Contact\Http\Requests\LandlordContractActionRequest;
use Litecms\Contact\Http\Resources\LandlordContractResource;
use Litecms\Contact\Models\LandlordContract;

/**
 * Admin web controller class.
 */
class LandlordContractActionController extends BaseController
{

    /**
     * Action controller function for landlord_contract.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LandlordContractActionRequest $request, LandlordContract $landlord_contract, $action)
    {
        try {
            $request = $request->all();
            $landlord_contract = LandlordContractAction::run($action, $landlord_contract, $request);

            $data = new LandlordContractResource($landlord_contract);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('contact::landlord_contract.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('contact/landlord_contract/' . $landlord_contract->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contact/landlord_contract/' . $landlord_contract->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
