<?php

namespace Litecms\Contact\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Contact\Http\Resources\ContactResource;
use Litecms\Contact\Http\Resources\ContactsCollection;
use Litecms\Contact\Scopes\LandlordContractPublicScope;
use Litecms\Contact\Models\LandlordContract;

class LandlordContractPublicController extends BaseController
{

    /**
     * Show landlord_contract's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = LandlordContract::pushScope(new RequestScope())
            ->pushScope(new LandlordContractPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $landlord_contracts = new LandlordContractsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('contact::landlord_contract.names'))
            ->view('contact::public.landlord_contract.index')
            ->data(compact('landlord_contracts', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show landlord_contract.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = LandlordContract::findBySlug($slug);
        $data = new LandlordContractResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('contact::landlord_contract.name'))
            ->view('contact::public.landlord_contract.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
