<?php

namespace Litecms\Contact\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litecms\Contact\Forms\LandlordContract as LandlordContractForm;
use Litecms\Contact\Http\Requests\LandlordContractResourceRequest;
use Litecms\Contact\Http\Resources\LandlordContractResource;
use Litecms\Contact\Http\Resources\LandlordContractsCollection;
use Litecms\Contact\Models\LandlordContract;
use Litecms\Contact\Actions\LandlordContractAction;
use Litecms\Contact\Actions\LandlordContractActions;


/**
 * Resource controller class for landlord_contract.
 */
class LandlordContractResourceController extends BaseController
{

    /**
     * Initialize landlord_contract resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = LandlordContractForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('litecms.contact.modules'), 'contact', guard_url('contact'));
            return $next($request);
        });
    }

    /**
     * Display a list of landlord_contract.
     *
     * @return Response
     */
    public function index(LandlordContractResourceRequest $request)
    {
        $request = $request->all();
        $page = LandlordContractActions::run('paginate', $request);

        $data = new LandlordContractsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('contact::landlord_contract.names'))
            ->view('contact::landlord_contract.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display landlord_contract.
     *
     * @param Request $request
     * @param Model   $landlord_contract
     *
     * @return Response
     */
    public function show(LandlordContractResourceRequest $request, LandlordContract $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new LandlordContractResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('contact::landlord_contract.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('contact::landlord_contract.show')
            ->output();
    }

    /**
     * Show the form for creating a new landlord_contract.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(LandlordContractResourceRequest $request, LandlordContract $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new LandlordContractResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('contact::landlord_contract.name'))
            ->view('contact::landlord_contract.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new landlord_contract.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LandlordContractResourceRequest $request, LandlordContract $model)
    {
        try {
            $request = $request->all();
            $model = LandlordContractAction::run('store', $model, $request);
            $data = new LandlordContractResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('contact::landlord_contract.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('contact/landlord_contract/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/contact/landlord_contract'))
                ->redirect();
        }

    }

    /**
     * Show landlord_contract for editing.
     *
     * @param Request $request
     * @param Model   $landlord_contract
     *
     * @return Response
     */
    public function edit(LandlordContractResourceRequest $request, LandlordContract $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new LandlordContractResource($model);
        // return view('contact::landlord_contract.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('contact::landlord_contract.name'))
            ->view('contact::landlord_contract.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the landlord_contract.
     *
     * @param Request $request
     * @param Model   $landlord_contract
     *
     * @return Response
     */
    public function update(LandlordContractResourceRequest $request, LandlordContract $model)
    {
        try {
            $request = $request->all();
            $model = LandlordContractAction::run('update', $model, $request);
            $data = new LandlordContractResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('contact::landlord_contract.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('contact/landlord_contract/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contact/landlord_contract/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the landlord_contract.
     *
     * @param Model   $landlord_contract
     *
     * @return Response
     */
    public function destroy(LandlordContractResourceRequest $request, LandlordContract $model)
    {
        try {

            $request = $request->all();
            $model = LandlordContractAction::run('destroy', $model, $request);
            $data = new LandlordContractResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('contact::landlord_contract.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('contact/landlord_contract/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contact/landlord_contract/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
