<?php

namespace Litecms\Contact\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Contact\Http\Resources\ContactResource;
use Litecms\Contact\Http\Resources\ContactsCollection;
use Litecms\Contact\Scopes\LandlordPublicScope;
use Litecms\Contact\Models\Landlord;

class LandlordPublicController extends BaseController
{

    /**
     * Show landlord's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Landlord::pushScope(new RequestScope())
            ->pushScope(new LandlordPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $landlords = new LandlordsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('contact::landlord.names'))
            ->view('contact::public.landlord.index')
            ->data(compact('landlords', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show landlord.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Landlord::findBySlug($slug);
        $data = new LandlordResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('contact::landlord.name'))
            ->view('contact::public.landlord.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
