<?php

namespace Litecms\Contact\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Contact\Actions\TenantAction;
use Litecms\Contact\Http\Requests\TenantActionRequest;
use Litecms\Contact\Http\Resources\TenantResource;
use Litecms\Contact\Models\Tenant;

/**
 * Admin web controller class.
 */
class TenantActionController extends BaseController
{

    /**
     * Action controller function for tenant.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(TenantActionRequest $request, Tenant $tenant, $action)
    {
        try {
            $request = $request->all();
            $tenant = TenantAction::run($action, $tenant, $request);

            $data = new TenantResource($tenant);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('contact::tenant.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('contact/tenant/' . $tenant->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contact/tenant/' . $tenant->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
