<?php

namespace Litecms\Contact\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Contact\Http\Requests\TenantActionsRequest;
use Litecms\Contact\Actions\TenantActions;

/**
 * Admin web controller class.
 */
class TenantActionsController extends BaseController
{

    /**
     * Action controller function for tenant.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(TenantActionsRequest $request, $action)
    {
        try {
            $tenant = TenantActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('contact::tenant.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('contact/tenant/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contact/tenant/' . $action))
                ->redirect();
        }
    }
}
