<?php

namespace Litecms\Contact\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Litecms\Contact\Actions\TenantExim;
use Litecms\Contact\Http\Requests\TenantEximRequest;

/**
 * Admin web controller class.
 */
class TenantEximController extends BaseController
{
    /**
     * Action controller function for tenant.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(TenantEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = TenantExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('contact:tenant.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('contact/tenant/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contact/tenant/' . $exim))
                ->redirect();
        }
    }
}
