<?php

namespace Litecms\Contact\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Contact\Http\Resources\ContactResource;
use Litecms\Contact\Http\Resources\ContactsCollection;
use Litecms\Contact\Scopes\TenantPublicScope;
use Litecms\Contact\Models\Tenant;

class TenantPublicController extends BaseController
{

    /**
     * Show tenant's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Tenant::pushScope(new RequestScope())
            ->pushScope(new TenantPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $tenants = new TenantsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('contact::tenant.names'))
            ->view('contact::public.tenant.index')
            ->data(compact('tenants', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show tenant.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Tenant::findBySlug($slug);
        $data = new TenantResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('contact::tenant.name'))
            ->view('contact::public.tenant.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
