<?php

namespace Litecms\Contact\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Contact\Http\Resources\ContactResource;
use Litecms\Contact\Http\Resources\ContactsCollection;
use Litecms\Contact\Scopes\VendorPublicScope;
use Litecms\Contact\Models\Vendor;

class VendorPublicController extends BaseController
{

    /**
     * Show vendor's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Vendor::pushScope(new RequestScope())
            ->pushScope(new VendorPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $vendors = new VendorsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('contact::vendor.names'))
            ->view('contact::public.vendor.index')
            ->data(compact('vendors', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show vendor.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Vendor::findBySlug($slug);
        $data = new VendorResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('contact::vendor.name'))
            ->view('contact::public.vendor.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
