<?php

namespace Litecms\Contact\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Contact\Events\DocumentAction as DocumentActionEvent;
use Litecms\Contact\Notifications\DocumentAction as DocumentActionNotification;
use Litepie\Actions\Concerns\AsAction;

class DocumentAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the DocumentActionEvent.
     *
     * @param   DocumentActionEvent  $event
     * @return mixed
     */
    public function handle(DocumentActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $document.
     *
     * @param   DocumentActionEvent  $event
     * @return void
     */
    public function create(DocumentActionEvent $event)
    {
        $client = $event->document->client;
        Notification::send($client, new DocumentActionNotification($event));
    }

    /**
     * Handle the DocumentActionEvent as a listener.
     *
     * @param   DocumentActionEvent  $event
     * @return mixed
     */
    public function asListener(DocumentActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   DocumentActionEvent  $event
     * @return bool
     */
    private function isAllowed(DocumentActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
