<?php

namespace Litecms\Contact\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Contact\Events\DocumentWorkflow as DocumentWorkflowEvent;
use Litecms\Contact\Notifications\DocumentWorkflow as DocumentWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class DocumentWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(DocumentWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $document is submitted.
     *
     * @param DocumentWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(DocumentWorkflowEvent $event)
    {
        $client = $event->document->client;
        Notification::send($client, new DocumentWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $document is published.
     *
     * @param DocumentWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(DocumentWorkflowEvent $event)
    {
        $client = $event->document->client;
        Notification::send($client, new DocumentWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $document is approved.
     *
     * @param DocumentWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(DocumentWorkflowEvent $event)
    {
        $client = $event->document->client;
        Notification::send($client, new DocumentWorkflowNotification($event));
    }

    /**
     * Handles the $document workflow event as a listener.
     *
     * @param DocumentWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(DocumentWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
