<?php

namespace Litecms\Contact\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Contact\Events\LandlordAction as LandlordActionEvent;
use Litecms\Contact\Notifications\LandlordAction as LandlordActionNotification;
use Litepie\Actions\Concerns\AsAction;

class LandlordAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the LandlordActionEvent.
     *
     * @param   LandlordActionEvent  $event
     * @return mixed
     */
    public function handle(LandlordActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $landlord.
     *
     * @param   LandlordActionEvent  $event
     * @return void
     */
    public function create(LandlordActionEvent $event)
    {
        $client = $event->landlord->client;
        Notification::send($client, new LandlordActionNotification($event));
    }

    /**
     * Handle the LandlordActionEvent as a listener.
     *
     * @param   LandlordActionEvent  $event
     * @return mixed
     */
    public function asListener(LandlordActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   LandlordActionEvent  $event
     * @return bool
     */
    private function isAllowed(LandlordActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
