<?php

namespace Litecms\Contact\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Contact\Events\LandlordContractAction as LandlordContractActionEvent;
use Litecms\Contact\Notifications\LandlordContractAction as LandlordContractActionNotification;
use Litepie\Actions\Concerns\AsAction;

class LandlordContractAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the LandlordContractActionEvent.
     *
     * @param   LandlordContractActionEvent  $event
     * @return mixed
     */
    public function handle(LandlordContractActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $landlord_contract.
     *
     * @param   LandlordContractActionEvent  $event
     * @return void
     */
    public function create(LandlordContractActionEvent $event)
    {
        $client = $event->landlord_contract->client;
        Notification::send($client, new LandlordContractActionNotification($event));
    }

    /**
     * Handle the LandlordContractActionEvent as a listener.
     *
     * @param   LandlordContractActionEvent  $event
     * @return mixed
     */
    public function asListener(LandlordContractActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   LandlordContractActionEvent  $event
     * @return bool
     */
    private function isAllowed(LandlordContractActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
