<?php

namespace Litecms\Contact\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Contact\Events\LandlordContractWorkflow as LandlordContractWorkflowEvent;
use Litecms\Contact\Notifications\LandlordContractWorkflow as LandlordContractWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class LandlordContractWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(LandlordContractWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $landlord_contract is submitted.
     *
     * @param LandlordContractWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(LandlordContractWorkflowEvent $event)
    {
        $client = $event->landlord_contract->client;
        Notification::send($client, new LandlordContractWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $landlord_contract is published.
     *
     * @param LandlordContractWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(LandlordContractWorkflowEvent $event)
    {
        $client = $event->landlord_contract->client;
        Notification::send($client, new LandlordContractWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $landlord_contract is approved.
     *
     * @param LandlordContractWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(LandlordContractWorkflowEvent $event)
    {
        $client = $event->landlord_contract->client;
        Notification::send($client, new LandlordContractWorkflowNotification($event));
    }

    /**
     * Handles the $landlord_contract workflow event as a listener.
     *
     * @param LandlordContractWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(LandlordContractWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
