<?php

namespace Litecms\Contact\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Contact\Events\LandlordWorkflow as LandlordWorkflowEvent;
use Litecms\Contact\Notifications\LandlordWorkflow as LandlordWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class LandlordWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(LandlordWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $landlord is submitted.
     *
     * @param LandlordWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(LandlordWorkflowEvent $event)
    {
        $client = $event->landlord->client;
        Notification::send($client, new LandlordWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $landlord is published.
     *
     * @param LandlordWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(LandlordWorkflowEvent $event)
    {
        $client = $event->landlord->client;
        Notification::send($client, new LandlordWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $landlord is approved.
     *
     * @param LandlordWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(LandlordWorkflowEvent $event)
    {
        $client = $event->landlord->client;
        Notification::send($client, new LandlordWorkflowNotification($event));
    }

    /**
     * Handles the $landlord workflow event as a listener.
     *
     * @param LandlordWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(LandlordWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
