<?php

namespace Litecms\Contact\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Contact\Events\TenantAction as TenantActionEvent;
use Litecms\Contact\Notifications\TenantAction as TenantActionNotification;
use Litepie\Actions\Concerns\AsAction;

class TenantAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the TenantActionEvent.
     *
     * @param   TenantActionEvent  $event
     * @return mixed
     */
    public function handle(TenantActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $tenant.
     *
     * @param   TenantActionEvent  $event
     * @return void
     */
    public function create(TenantActionEvent $event)
    {
        $client = $event->tenant->client;
        Notification::send($client, new TenantActionNotification($event));
    }

    /**
     * Handle the TenantActionEvent as a listener.
     *
     * @param   TenantActionEvent  $event
     * @return mixed
     */
    public function asListener(TenantActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   TenantActionEvent  $event
     * @return bool
     */
    private function isAllowed(TenantActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
