<?php

namespace Litecms\Contact\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Contact\Events\TenantWorkflow as TenantWorkflowEvent;
use Litecms\Contact\Notifications\TenantWorkflow as TenantWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class TenantWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(TenantWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $tenant is submitted.
     *
     * @param TenantWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(TenantWorkflowEvent $event)
    {
        $client = $event->tenant->client;
        Notification::send($client, new TenantWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $tenant is published.
     *
     * @param TenantWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(TenantWorkflowEvent $event)
    {
        $client = $event->tenant->client;
        Notification::send($client, new TenantWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $tenant is approved.
     *
     * @param TenantWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(TenantWorkflowEvent $event)
    {
        $client = $event->tenant->client;
        Notification::send($client, new TenantWorkflowNotification($event));
    }

    /**
     * Handles the $tenant workflow event as a listener.
     *
     * @param TenantWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(TenantWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
