<?php
namespace Litecms\Contact\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Contact\Events\DocumentAction as DocumentActionEvent;
use Litecms\Contact\Models\Document;

class DocumentAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $document;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param DocumentActionEvent $document
     */
    public function __construct(DocumentActionEvent $document)
    {
        $this->action = $event->action;
        $this->document = $document;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Document Approved - ' . config('app.name'))
            ->view('contact::document.email.action', ['data' => $this->document]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
