<?php
namespace Litecms\Contact\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Contact\Events\LandlordAction as LandlordActionEvent;
use Litecms\Contact\Models\Landlord;

class LandlordAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $landlord;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param LandlordActionEvent $landlord
     */
    public function __construct(LandlordActionEvent $landlord)
    {
        $this->action = $event->action;
        $this->landlord = $landlord;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Landlord Approved - ' . config('app.name'))
            ->view('contact::landlord.email.action', ['data' => $this->landlord]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
