<?php
namespace Litecms\Contact\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Contact\Events\LandlordContractAction as LandlordContractActionEvent;
use Litecms\Contact\Models\LandlordContract;

class LandlordContractAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $landlord_contract;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param LandlordContractActionEvent $landlord_contract
     */
    public function __construct(LandlordContractActionEvent $landlord_contract)
    {
        $this->action = $event->action;
        $this->landlord_contract = $landlord_contract;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('LandlordContract Approved - ' . config('app.name'))
            ->view('contact::landlord_contract.email.action', ['data' => $this->landlord_contract]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
