<?php
namespace Litecms\Contact\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Contact\Events\TenantAction as TenantActionEvent;
use Litecms\Contact\Models\Tenant;

class TenantAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $tenant;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param TenantActionEvent $tenant
     */
    public function __construct(TenantActionEvent $tenant)
    {
        $this->action = $event->action;
        $this->tenant = $tenant;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Tenant Approved - ' . config('app.name'))
            ->view('contact::tenant.email.action', ['data' => $this->tenant]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
