<?php

namespace Litecms\Contact\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Contact\Models\Document;

class DocumentPolicy
{

    use DocumentAction;

    /**
     * Determine if the given user can view the document.
     *
     * @param Authenticatable $user
     * @param Document $document
     *
     * @return bool
     */
    public function view(Authenticatable $user, Document $document)
    {
        if ($authUser->canDo('contact.document.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $document->is_owner;
    }

    /**
     * Determine if the given user can create a document.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('contact.document.create');
    }

    /**
     * Determine if the given user can update the given document.
     *
     * @param Authenticatable $user
     * @param Document $document
     *
     * @return bool
     */
    public function update(Authenticatable $user, Document $document)
    {
        if ($user->canDo('contact.document.edit') && $user->isAdmin()) {
            return true;
        }

        return $document->is_owner;
    }

    /**
     * Determine if the given user can delete the given document.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Document $document)
    {
        return $document->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
