<?php

namespace Litecms\Contact\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Contact\Models\LandlordContract;

class LandlordContractPolicy
{

    use LandlordContractAction;
    use LandlordContractWorkflow;

    /**
     * Determine if the given user can view the landlord_contract.
     *
     * @param Authenticatable $user
     * @param LandlordContract $landlord_contract
     *
     * @return bool
     */
    public function view(Authenticatable $user, LandlordContract $landlord_contract)
    {
        if ($authUser->canDo('contact.landlord_contract.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $landlord_contract->is_owner;
    }

    /**
     * Determine if the given user can create a landlord_contract.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('contact.landlord_contract.create');
    }

    /**
     * Determine if the given user can update the given landlord_contract.
     *
     * @param Authenticatable $user
     * @param LandlordContract $landlord_contract
     *
     * @return bool
     */
    public function update(Authenticatable $user, LandlordContract $landlord_contract)
    {
        if ($user->canDo('contact.landlord_contract.edit') && $user->isAdmin()) {
            return true;
        }

        return $landlord_contract->is_owner;
    }

    /**
     * Determine if the given user can delete the given landlord_contract.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, LandlordContract $landlord_contract)
    {
        return $landlord_contract->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
