<?php

namespace Litecms\Contact\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Contact\Models\Landlord;

class LandlordPolicy
{

    use LandlordAction;
    use LandlordWorkflow;

    /**
     * Determine if the given user can view the landlord.
     *
     * @param Authenticatable $user
     * @param Landlord $landlord
     *
     * @return bool
     */
    public function view(Authenticatable $user, Landlord $landlord)
    {
        if ($authUser->canDo('contact.landlord.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $landlord->is_owner;
    }

    /**
     * Determine if the given user can create a landlord.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('contact.landlord.create');
    }

    /**
     * Determine if the given user can update the given landlord.
     *
     * @param Authenticatable $user
     * @param Landlord $landlord
     *
     * @return bool
     */
    public function update(Authenticatable $user, Landlord $landlord)
    {
        if ($user->canDo('contact.landlord.edit') && $user->isAdmin()) {
            return true;
        }

        return $landlord->is_owner;
    }

    /**
     * Determine if the given user can delete the given landlord.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Landlord $landlord)
    {
        return $landlord->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
