<?php

namespace Litecms\Contact\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Contact\Models\Tenant;

class TenantPolicy
{

    use TenantAction;
    use TenantExim;
    use TenantWorkflow;

    /**
     * Determine if the given user can view the tenant.
     *
     * @param Authenticatable $user
     * @param Tenant $tenant
     *
     * @return bool
     */
    public function view(Authenticatable $user, Tenant $tenant)
    {
        if ($authUser->canDo('contact.tenant.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $tenant->is_owner;
    }

    /**
     * Determine if the given user can create a tenant.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('contact.tenant.create');
    }

    /**
     * Determine if the given user can update the given tenant.
     *
     * @param Authenticatable $user
     * @param Tenant $tenant
     *
     * @return bool
     */
    public function update(Authenticatable $user, Tenant $tenant)
    {
        if ($user->canDo('contact.tenant.edit') && $user->isAdmin()) {
            return true;
        }

        return $tenant->is_owner;
    }

    /**
     * Determine if the given user can delete the given tenant.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Tenant $tenant)
    {
        return $tenant->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
