<?php

namespace Litecms\Contact\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Litecms\Contact\Models\Vendor;
use Litecms\Contact\Models\Tenant;
use Litecms\Contact\Models\Landlord;
use Litecms\Contact\Models\Document;
use Litecms\Contact\Models\LandlordContract;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litecms\Contact\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/contact/vendor/*')) {
            Route::bind('vendor', function ($vendor) {
                return Vendor::findorNew($vendor);
            });
        }
        if (Request::is('*/contact/tenant/*')) {
            Route::bind('tenant', function ($tenant) {
                return Tenant::findorNew($tenant);
            });
        }
        if (Request::is('*/contact/landlord/*')) {
            Route::bind('landlord', function ($landlord) {
                return Landlord::findorNew($landlord);
            });
        }
        if (Request::is('*/contact/document/*')) {
            Route::bind('document', function ($document) {
                return Document::findorNew($document);
            });
        }
        if (Request::is('*/contact/landlord_contract/*')) {
            Route::bind('landlord_contract', function ($landlord_contract) {
                return LandlordContract::findorNew($landlord_contract);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
